 /*BASIC CSS FILE FOR ALL TEMPLATES*/


/* BASIC UTIL CLASSES */
.clear-fix{
	clear: both !important;
}



/* CONTROL PANEL */

.control_panel_div{
	color: white;
	margin: 0 0 10px 0;
	border: 1px solid gray;
	padding: 0 0 6px 0;
	background-color:#666666;
	border-radius:3px;
}

.control_panel_div h2{
	color: white;
	background-color: #383838;
	margin: 0;
	padding: 9px;
	font-size: 1.1em;
	border-top-left-radius:3px;
	border-top-right-radius:3px;
}

.control_panel_div h2>span{
	margin: 0 0 0 6px;
}

/*MAIL*/
.mail {
	background:#666;
	margin-bottom:0px;
	padding:10px 10px 0px 10px;
	text-align:left;
	border: 1px solid grey;
}
.mail h2 {
	font-size:1em;
	font-weight:bold;
/*	text-transform:uppercase;
*/	color:#fff;
	background:#333;
	margin:-10px -10px 0 -10px;
	padding:6px 12px;
	text-align:left;

}
.mail h2 a,
.mail h2 a.visible {
	color:#fff;
	background:#333 url("../img/switch_minus.gif") 96% 50% no-repeat;
	display:block;
	padding:6px 12px;
	margin:-6px -12px;
	border:0px;
	text-align:left;

}

.text_mail
{
	float:left;
}

.radio_mail
{
	float:left;
	font-size:0.9em;
	margin: 8px 0px 0px 0px;
}

.button_mail
{
	float:left;
	font-size:1em;
	margin: 8px 0px 0px 0px;
}




/* SHORTCUTS */
.shortcuts_container{
	float:right;
}

.shortcuts_container .ui-button-text{
	font-size: 1em;
}



/* REFRESH TIME */
.refresh_time_container{
	float:right;
	padding-right: 12px;
	line-height: 6pt;
	font-size: 10px;
	vertical-align: middle;
}

.timer_refresh_btn{
	margin: 0 0 0 6px;
	font-size: 1em !important;
	padding:2.5px 10px 2.5px 10px !important;

}

.refresh_time_container p{
	margin: 0;
	line-height: 21px;
}
.refresh_time_container p, 
.refresh_time_container input,
.refresh_time_container span{
	float: left;
}

.time_left_span{
	display: block;
	min-width: 18px;
	margin: 0 1px 0 9px;
}


/* EXCEL/CSV EXPORT */
.excel_container{
	float: right;
	line-height: 6pt;
	font-size: 10px;
	margin: -5px 6px 0 0;
}

.excel_container .ui-button-text{
	font-size: 0.8em;
}
.csvupdate_frm{
	text-align: center;
	margin-bottom:5px;
}
.csvupload_container{

	box-shadow: 8px 8px 4px #555;
	/*color: red;*/
}
.csvupload_container li{
	float: left;
	margin-left: 6px;
	line-height: 20px;
}
.validatecsv_container li{
	float:none !important;
}
.validatecsv_container, .loadcsv_container{
	border-top: white solid 1px;
	background-color:#777;
	padding: 5px;
}
.validatecsv_container .validatecsv_lines{
	float:left;
}
.validatecsv_container .validatecsv_lines .validatecsv_line{
	font-size:1.2em;
	padding:3px;
}
.validatecsv_container .validatecsv_form{
	float: right;
}

.csv_buttons{
	margin-top: 4px; 
	text-align:center;
}

/*.csvload_table > tbody > tr:first-child > td{
	font-weight:bold !important;
	color: #4d4;
}

.csvload_table td{
	padding: 2px;
	font-weight:normal;
	border: 1px solid #ddd;
}*/

/* FILTERS */

form[id*="_filters_form"]{
	float: left;
}
.tag_date_filters{
	float: left;
	margin: 0 0 0px 10px;
}
.tag_date_filters label{
	margin: 0 6px 0 6px;
	min-width: 120px;
}

.tag_select_filters{
	float: left;
	margin: 0;
}

.tag_select_filters p{
	float: left;
	margin: 1px 5px 1px 0;
}

.tag_select_filters p label{
	text-align: right;
	display: block;
	/*min-width: 84px;*/
	float:left;
	font-size: 0.9em;
}

.tag_select_filters p select{
	float: left;
	background: black;
	border-color: gray;
	min-width: 150px;
	border-radius:3px;
	color:white;
	margin: 3px;
	line-height: 18px;
}


.label_filter_btn{
	min-width: 120px;
}

.p_label_input_filter input[type="button"]{
	font-size: 0.9em;
	padding:1px;
	margin: 3px 6px 0 0;
	float: right;
}



div[id*="_div_select_filters"] .label_filter,
div[id*="_div_select_filters"] .label_filter_btn {
	min-width: 120px;
	text-align: right;
	margin-right: 3px;
	margin-top:5px;

}

.tag_search_clear_btn{
	padding: 6px 0px 0 120px;
	font-size: 0.9em;
}

/* GROUP BY TAG */
.group_by_and_div{
	margin: 4px 0 0 0;
	vertical-align: middle;
}

.group_by_and_title{
	min-width: 90px;
	float: left;
	display: block;
	text-align: right;
	margin: 0 6px 0 0;
	font-size: 0.9em;
	line-height: 24px;
}

.group_by_and_div .ui-button-text{
	font-size: 0.9em;
}

.group_by_and_div div{
	float: left;
	margin: 0 0 0 12px;
}

/* GRID */
.div_grid_container{
	margin: 0 0 10px 0;
}

/* HIGHCHARTS */
.highcharts_container {
	min-width: 400px;
	height: 400px; 
	margin: 0 auto
}

/* INTERRUPTOR */
.interruptor{
	min-width:100px; 
	float:left;
}

#stage{
	width:18%;
}

